==> matplotlib_colors-1.0.14-py3-none-any.whl: matplotlib_colors/colors.py <==

# RGB values
TEAM = [120, 211, 242]
OPPOSITION = [220, 58, 68]
CONTESTED = [211, 211, 211]

PL_WIN = [19, 205, 0]
PL_DRAW = [117, 117, 110]
PL_LOSE = [216, 25, 32]

PL_PURPLE = [55, 0, 60]
PL_GREEN = [0, 255, 135]
PL_BLUE = [2, 238, 255]
PL_PINK = [255, 40, 130]
PL_RED = [233, 0, 82]

ANALYST_RED = [224, 86, 95]
ANALYST_BLUE = [121, 70, 205]
ANALYST_WHITE = [247, 247, 247]
ANALYST_PURPLE = [29, 10, 48]

DUKE_BLUE = [57, 0, 153]
JAZZBERRY_JAM = [158,0,89]
RADICAL_RED = [255,0,84]
ORANGE_PANTONE = [255,84,0]
AMBER = [255, 189, 0]

MIDNIGHT_BLUE = [3, 4, 94]
DARK_CORNFLOWER = [2, 62, 138]
STAR_COMMAND_BLUE = [0, 119, 182]
BLUE_GREEN = [0, 150, 199]
PACIFIC_BLUE = [0, 180, 216]
SKY_BLUE_CRAYOLA = [72, 202, 228]
MIDDLE_BLUE = [144, 224, 239]
BLIZZARD_BLUE = [144, 224, 239]
LIGHT_CYAN = [202, 240, 248]

RICH_BLACK_FOGRA_29 = [0, 18, 25]
BLUE_SAPPHIRE = [0, 95, 115]
VIRIDIAN_GREEN = [10, 147, 150]
MIDDLE_BLUE_GREEN = [148, 210, 189]
MEDIUM_CHAMPAGNE = [233, 216, 166]
GAMBOGE = [238, 155, 0]
ALLOY_ORANGE = [202, 103, 2]
RUST = [187, 62, 3]
RUFOUS = [174, 32, 18]
RUBY_RED = [155, 34, 38]

RICH_BLACK_FOGRA_29 = [13, 27, 42]
OXFORD_BLUE = [27, 38, 59]
BDAZZLED_BLUE = [65, 90, 119]
SHADOW_BLUE = [119, 141, 169]
PLATINUM = [224, 225, 221]

FLICKR_PINK = [247, 37, 133]
PURPLE = [114, 9, 183]
TRYPAN_BLUE = [58, 12, 163]
ULTRAMARINE_BLUE = [67, 97, 238]
VIVID_SKY_BLUE = [76, 201, 240]

colors = {var: list(map(lambda x: x/255, eval(var))) 
          for var in dir() 
          if not var.startswith('__')}

color_names = list(colors.keys())

==> matplotlib_colors-1.0.15-py3-none-any.whl: matplotlib_colors/colors.py <==

# RGB values
TEAM = [120, 211, 242]
OPPOSITION = [220, 58, 68]
CONTESTED = [211, 211, 211]

PL_WIN = [19, 205, 0]
PL_DRAW = [117, 117, 110]
PL_LOSE = [216, 25, 32]

PL_PURPLE = [55, 0, 60]
PL_GREEN = [0, 255, 135]
PL_BLUE = [2, 238, 255]
PL_PINK = [255, 40, 130]
PL_RED = [233, 0, 82]

ANALYST_RED = [224, 86, 95]
ANALYST_BLUE = [121, 70, 205]
ANALYST_WHITE = [247, 247, 247]
ANALYST_PURPLE = [29, 10, 48]

DUKE_BLUE = [57, 0, 153]
JAZZBERRY_JAM = [158,0,89]
RADICAL_RED = [255,0,84]
ORANGE_PANTONE = [255,84,0]
AMBER = [255, 189, 0]

MIDNIGHT_BLUE = [3, 4, 94]
DARK_CORNFLOWER = [2, 62, 138]
STAR_COMMAND_BLUE = [0, 119, 182]
BLUE_GREEN = [0, 150, 199]
PACIFIC_BLUE = [0, 180, 216]
SKY_BLUE_CRAYOLA = [72, 202, 228]
MIDDLE_BLUE = [144, 224, 239]
BLIZZARD_BLUE = [144, 224, 239]
LIGHT_CYAN = [202, 240, 248]

RICH_BLACK_FOGRA_29 = [0, 18, 25]
BLUE_SAPPHIRE = [0, 95, 115]
VIRIDIAN_GREEN = [10, 147, 150]
MIDDLE_BLUE_GREEN = [148, 210, 189]
MEDIUM_CHAMPAGNE = [233, 216, 166]
GAMBOGE = [238, 155, 0]
ALLOY_ORANGE = [202, 103, 2]
RUST = [187, 62, 3]
RUFOUS = [174, 32, 18]
RUBY_RED = [155, 34, 38]

RICH_BLACK_FOGRA_29 = [13, 27, 42]
OXFORD_BLUE = [27, 38, 59]
BDAZZLED_BLUE = [65, 90, 119]
SHADOW_BLUE = [119, 141, 169]
PLATINUM = [224, 225, 221]

FLICKR_PINK = [247, 37, 133]
PURPLE = [114, 9, 183]
TRYPAN_BLUE = [58, 12, 163]
ULTRAMARINE_BLUE = [67, 97, 238]
VIVID_SKY_BLUE = [76, 201, 240]

colors = {var.lower(): list(map(lambda x: x/255, eval(var))) 
          for var in dir() 
          if not var.startswith('__')}

color_names = list(colors.keys())
